@@ -12,8 +12,13 @@ from json_to_csv import read_csv
 import time
 from eurlex_scraping import *
 from cellar import *
-
+from sparql import *
 
 if __name__ == '__main__':
-    data,full= get_cellar_extra(sd='2023-01-01',save_file='n',max_ecli=300)
+    username = "n00ac9w5"
+    password = "XUtjyPDrl1c"
+    base_query = "SELECT DN,CI WHERE DN = %s"
+    input = " OR ".join(['62004CJ0292'])
+    query = base_query % (str(input))
+    response = run_eurlex_webservice_query(query, username, password)
     b=2
\ No newline at end of file
