@@ -143,7 +143,7 @@ def add_sections(data, threads, json_filepath=None):
     add_column_frow_list(data, "celex_eurovoc", list_eurovoc)
     add_column_frow_list(data, "celex_directory_codes", list_codes)
     add_column_frow_list(data, 'advocate_general', list_adv)
-    add_column_frow_list(data, 'judge-rapporteur', list_judge)
+    add_column_frow_list(data, 'judge_rapporteur', list_judge)
     add_column_frow_list(data, 'affecting_ids', list_affecting_id)
     add_column_frow_list(data, 'affecting_strings', list_affecting_str)
     if json_filepath:
